@@ -218,3 +218,8 @@ class IntercomClient(object):
 
     def post(self, path, **kwargs):
         return self.request('POST', path=path, **kwargs)
+
+    def perform(self, method, path, **kwargs):
+        if method=='POST':
+            return self.post(path, **kwargs)
+        return self.get(path, **kwargs)
