@@ -1,3 +1,6 @@
+import math as m
+
+
 # De-nest each list node up to record level
 def denest_list_nodes(this_json, data_key, list_nodes):
     new_json = this_json
@@ -52,3 +55,26 @@ def transform_json(this_json, stream_name, data_key):
     if data_key in new_json:
         return new_json[data_key]
     return new_json
+
+
+def find_datetimes_in_schema(schema):
+    datetimes = []
+    for element, value in schema['properties'].items():
+        if 'format' in value and value['format'] == 'date-time':
+            datetimes.append(element)
+    return datetimes
+
+def get_integer_places(value):
+    if value <= 999999999999997:
+        return int(m.log10(value)) + 1
+    counter = 15
+    while value >= 10**counter:
+        counter += 1
+    return counter
+
+# Only want to transform seconds to millis here
+def transform_epochs(record, schema_datetimes):
+    for datetime in schema_datetimes:
+        if datetime in record and record[datetime] and get_integer_places(
+                record[datetime]) == 10:
+            record[datetime] = record[datetime] * 1000
